@@ -1,7 +1,9 @@
 #ifndef VKGALLERY_H
 #define VKGALLERY_H
 
+#ifdef ENABLE_NOTIFY
 #include <libnotify/notify.h>
+#endif
 
 #include <QMainWindow>
 #include <QDebug>
@@ -27,6 +29,7 @@ extern "C" {
 
 #include "widgets/uiaccountsettings.h"
 #include "widgets/uinetworksettings.h"
+#include "widgets/qphotouploader.h"
 #include "ui/uiapplicationsettings.h"
 #include "widgets/uihelp.h"
 #include "ui_vkgallery.h"
@@ -51,8 +54,12 @@ public:
     VKGallery(QWidget *parent = 0);
     ~VKGallery();
 
+signals:
+    void closeDialogs();
+
 protected:
     void changeEvent(QEvent *e);
+    void closeEvent(QCloseEvent *e); 
 
 private:
     QFont usedFont;
@@ -77,6 +84,7 @@ private slots:
     void actionAppSettings_toggled();
 
     void actionFull_screen_toggled();
+    void actionUploadPhoto_toggled();
 
     void help();
     void about();
@@ -84,7 +92,7 @@ private slots:
     void settingsUpdated();
     void openImage(Photo photo);
 
-    void gotErrorMsg(QString errorMsg, QTransport::Action acc);
+    void gotErrorMsg(QString errorMsg, QTransport::Action acc, bool isMajor);
 };
 
 #endif // VKGALLERY_H
